==> react-atom-input-5.26.0.tgz: package/lib/Mask/useMask.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useEffect } from 'react';
import { useIMask } from 'react-imask';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { isFunction } from '../config.js';
var useMask = function useMask(_ref) {
  var argValue = _ref.value,
    argDefaultValue = _ref.defaultValue,
    mask = _ref.mask,
    onChange = _ref.onChange,
    _onComplete = _ref.onComplete,
    forwardedRef = _ref.forwardedRef;
  var _useControlledState = useControlledState(argValue, argDefaultValue),
    value = _useControlledState[0];
  var _useIMask = useIMask(_extends({}, mask), {
      onAccept: function onAccept(value, maskRef, event) {
        for (var _len = arguments.length, args = new Array(_len > 3 ? _len - 3 : 0), _key = 3; _key < _len; _key++) {
          args[_key - 3] = arguments[_key];
        }
        return isFunction(onChange) && onChange(event, _extends({
          value: value,
          maskRef: maskRef
        }, args));
      },
      onComplete: function onComplete(value, maskRef, event) {
        for (var _len2 = arguments.length, args = new Array(_len2 > 3 ? _len2 - 3 : 0), _key2 = 3; _key2 < _len2; _key2++) {
          args[_key2 - 3] = arguments[_key2];
        }
        return isFunction(_onComplete) && _onComplete(event, _extends({
          value: value,
          maskRef: maskRef
        }, args));
      }
    }),
    refInput = _useIMask.ref,
    _useIMask$value = _useIMask.value,
    maskedValue = _useIMask$value === void 0 ? '' : _useIMask$value,
    setValue = _useIMask.setValue;
  var ref = useMergeRefs(refInput, forwardedRef);
  useEffect(function () {
    return value !== maskedValue && setValue(maskedValue);
  }, [argValue, setValue, maskedValue, value]);
  return Object.assign([maskedValue, ref], {
    maskedValue: maskedValue,
    ref: ref
  });
};
export default useMask;

==> react-atom-input-5.30.0.tgz: package/lib/Mask/useMask.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { useEffect } from 'react';
import { useIMask } from 'react-imask';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState';
import useMergeRefs from '@s-ui/react-hooks/lib/useMergeRefs';
import { isFunction } from '../config.js';
var useMask = function useMask(_ref) {
  var argValue = _ref.value,
    argDefaultValue = _ref.defaultValue,
    mask = _ref.mask,
    onChange = _ref.onChange,
    _onComplete = _ref.onComplete,
    forwardedRef = _ref.forwardedRef;
  var _useControlledState = useControlledState(argValue, argDefaultValue),
    value = _useControlledState[0];
  var _useIMask = useIMask(_extends({}, mask), {
      onAccept: function onAccept(value, maskRef, event) {
        for (var _len = arguments.length, args = new Array(_len > 3 ? _len - 3 : 0), _key = 3; _key < _len; _key++) {
          args[_key - 3] = arguments[_key];
        }
        return isFunction(onChange) && maskedValue !== '' && onChange(event, _extends({
          value: value,
          maskRef: maskRef
        }, args));
      },
      onComplete: function onComplete(value, maskRef, event) {
        for (var _len2 = arguments.length, args = new Array(_len2 > 3 ? _len2 - 3 : 0), _key2 = 3; _key2 < _len2; _key2++) {
          args[_key2 - 3] = arguments[_key2];
        }
        return isFunction(_onComplete) && _onComplete(event, _extends({
          value: value,
          maskRef: maskRef
        }, args));
      }
    }),
    refInput = _useIMask.ref,
    _useIMask$value = _useIMask.value,
    maskedValue = _useIMask$value === void 0 ? '' : _useIMask$value,
    setValue = _useIMask.setValue;
  var ref = useMergeRefs(refInput, forwardedRef);
  useEffect(function () {
    return value !== maskedValue && setValue(maskedValue);
  }, [argValue, setValue, maskedValue, value]);
  return Object.assign([maskedValue, ref], {
    maskedValue: maskedValue,
    ref: ref
  });
};
export default useMask;
